![](https://user-images.githubusercontent.com/52009346/68560531-cef88400-0441-11ea-845c-9e5e4ab1f53b.png)

## Contributors

* **Juan Camilo Gonzalez Angarita** - [jcamiloangarita](https://github.com/jcamiloangarita)
* **Muhammad Suleman** - [msfazal](https://github.com/msfazal)
* **Eirik Lyngvi** - [elyngvi](https://github.com/elyngvi)
* **Magnus Tvedt** - [magnusbj](https://github.com/magnusbj)

See the full list of [contributors](https://github.com/pro-well-plan/pwptemp/graphs/contributors) involved in this project.

## Introduction
Pwptemp is a small LGPL licensed library for easy calculation of the
temperature distribution along the well. Features are added as they
are needed; suggestions and contributions of all kinds are very welcome.

To catch up on the latest development and features, see the [changelog](CHANGELOG.md).

## Getting Started

These instructions will get you a copy of the project up and running on your local machine for development and testing purposes.

### Get pwptemp

* Users: Wheels for Python from [PyPI](https://pypi.python.org/pypi/pwptemp/) 
    * `pip install pwptemp`
* Developers: Source code from [github](https://github.com/pro-well-plan/pwptemp)
    * `git clone https://github.com/pro-well-plan/pwptemp`
    
## Contributing

Please read [CONTRIBUTING](CONTRIBUTING.md) for details on our code of conduct, and the process for submitting pull requests to us.

## Versioning

We use [SemVer](http://semver.org/) for versioning. For the versions available, see the [tags on this repository](https://github.com/pro-well-plan/pwptemp/tags). 

## History ##
Pwptemp was initially written and is maintained by [Pro Well Plan
AS](http://www.prowellplan.com/) as a free, simple, easy-to-use way of getting
temperature data that can be tailored to our needs, and as contribution to the
free software community.

## License

This project is licensed under the GNU Lesser General Public License v3.0 - see the [LICENSE](LICENSE.md) file for details


*for further information contact juan@prowellplan.com*
